@@ -14,7 +14,7 @@ class BillInvoices(Resource):
         self.urls = {
             "new": f"/companies/{super().get_company_id()}/invoices",
             "edit": f"/companies/{super().get_company_id()}/invoices",
-            "import": f"/companies/{super().get_company_id()}/import_bills",
+            "import": f"/companies/{super().get_company_id()}/import_invoices?type=PurchaseInvoice",
         }
 
         super().set_urls(self.urls)
@@ -181,7 +181,7 @@ class BillInvoices(Resource):
 
             # If client type is MS_DYNAMICS
             elif super().get_client_type() == super().MS_DYNAMICS:
-                data.pop("type")
+                # data.pop("type")
                 data.update({
                     "vendor_number": f'{payload.get("vendor_id", "")}',
                     "vendor_invoice_no": f'{payload.get("vendor_invoice_no", "")}',
