@@ -163,6 +163,16 @@ class Items(Resource):
                         "sku": payload.get("item_code", "")
                     })
 
+                if 'item_code' in payload.keys():
+                    data.update({
+                        "sku": payload.get("item_code", "")
+                    })
+
+                if 'value' in payload.keys():
+                    data.update({
+                        "rate": payload.get("value", "")
+                    })
+
             # If client type is XERO
             elif super().get_client_type() == super().XERO:
 
@@ -206,7 +216,7 @@ class Items(Resource):
                 data.update({
                     "description": f'{payload.get("description", "")}',
                     "baseUnitOfMeasure": f'{payload.get("base_unit_of_measure", "")}',
-                    "unitPrice": payload.get("unit_price", 0),
+                    "unitPrice": payload.get("value", 0),
                 })
 
             data.update(payload.get("additional_properties", {}))
