@@ -109,7 +109,7 @@ class Payments(Resource):
 
                 if 'amount' in payload.keys():
                     data.update({
-                        "TotalAmt": int(payload.get("amount", 0))
+                        "TotalAmt": int(float(payload.get("amount", 0)))
                     })
 
                 if 'customer_id' in payload.keys():
@@ -142,9 +142,9 @@ class Payments(Resource):
 
                 for i in range(len(invoices)): 
                     if i == 0:
-                        if 'reference' in invoices[i].keys():
+                        if 'payment_reference' in invoices[i].keys():
                             data.update({
-                                "PaymentRefNum": invoices[i].pop('reference')
+                                "PaymentRefNum": invoices[i].pop('payment_reference')
                             })
                     
                     if 'payment_date' in invoices[i].keys():
@@ -157,7 +157,7 @@ class Payments(Resource):
                     invoice = {}
                     if 'amount' in invoices[i].keys():
                         invoice.update({
-                            "Amount": int(invoices[i].get("amount", 0))
+                            "Amount": int(float(invoices[i].get("amount", 0)))
                         })
 
                     if 'invoice_id' in invoices[i].keys():
@@ -214,9 +214,9 @@ class Payments(Resource):
 
                 for i in range(len(invoices)): 
                     if i == 0:
-                        if 'reference' in invoices[i].keys():
+                        if 'payment_reference' in invoices[i].keys():
                             payment.update({
-                                "reference_number": invoices[i].pop('reference')
+                                "reference_number": invoices[i].pop('payment_reference')
                             })
                     if 'invoice_id' in invoices[i].keys():
                         invoices[i]['invoice_id'] = invoices[i].pop(
@@ -307,9 +307,9 @@ class Payments(Resource):
                     if 'payment_date' in invoice_payments[i].keys():
                         invoice_payments[i]['PaymentDate'] = invoice_payments[i].pop(
                             'payment_date')
-                    if 'reference' in invoice_payments[i].keys():
+                    if 'payment_reference' in invoice_payments[i].keys():
                         invoice_payments[i]['PaymentReference'] = invoice_payments[i].pop(
-                            'reference')
+                            'payment_reference')
                     if 'payment_type' in invoice_payments[i].keys():
                         invoice_payments[i]['PaymentType'] = invoice_payments[i].pop(
                             'payment_type')
@@ -317,7 +317,7 @@ class Payments(Resource):
                         invoice_payments[i]['Account'] = invoice_payments[i].pop(
                             'account_id')
                     if 'amount' in invoice_payments[i].keys():
-                        invoice_payments[i]['Amount'] = int(invoice_payments[i].pop('amount'))
+                        invoice_payments[i]['Amount'] = int(float(invoice_payments[i].pop('amount')))
                     
                     if 'invoice_id' in invoice_payments[i].keys():
                         invoice_payments[i].pop('invoice_id')
@@ -348,7 +348,7 @@ class Payments(Resource):
 
                 # if 'amount' in payload.keys():
                 #     payment.update({
-                #         "Amount": int(payload.get("amount", 0))
+                #         "Amount": int(float(payload.get("amount", 0)))
                 #     })
 
                 # if 'reference' in payload.keys():
@@ -380,11 +380,11 @@ class Payments(Resource):
                         }) 
                     if 'amount' in invoice[0].keys():
                         payment.update({
-                            "Amount": int(invoice[0].pop('amount'))
+                            "Amount": int(float(invoice[0].pop('amount')))
                         })
-                    if 'reference' in invoice[0].keys():
+                    if 'payment_reference' in invoice[0].keys():
                         payment.update({
-                            "Reference": invoice[0].pop('reference')
+                            "Reference": invoice[0].pop('payment_reference')
                         }) 
                     
                     if 'payment_date' in invoice[0].keys():
@@ -402,8 +402,8 @@ class Payments(Resource):
                 data = {
                     "partner_type": "customer",
                     "date": payload.get("date", ""),
-                    "amount": int(payload.get("amount", 0)),
-                    "partner_id": int(payload.get("customer_id", 0)),
+                    "amount": int(float(payload.get("amount", 0))),
+                    "partner_id": int(float(payload.get("customer_id", 0))),
                     # "payment_reference": payload.get("reference", ""),
                 }
 
@@ -411,13 +411,13 @@ class Payments(Resource):
 
                 for i in range(len(invoices)):                    
                     if i == 0:
-                        if 'reference' in invoices[i].keys():
-                            data['payment_reference'] = invoices[i].pop('reference')
+                        if 'payment_reference' in invoices[i].keys():
+                            data['payment_reference'] = invoices[i].pop('payment_reference')
 
                     if "invoice_id" in invoices[i].keys():
                         invoices[i]["invoice_id"] = invoices[i].pop("invoice_id")
                     if "amount" in invoices[i].keys():
-                        invoices[i]["amount"] = int(invoices[i].pop("amount"))
+                        invoices[i]["amount"] = int(float(invoices[i].pop("amount")))
 
                     if 'payment_date' in invoices[i].keys():
                         invoices[i].pop('payment_date')
@@ -449,13 +449,13 @@ class Payments(Resource):
                         data.update({
                             "ownerInvoiceNumber": invoice[0].pop("invoice_id"),
                         }) 
-                    if 'reference' in invoice[0].keys():
+                    if 'payment_reference' in invoice[0].keys():
                         data.update({
-                            "paymentReference": invoice[0].pop('reference')
+                            "paymentReference": invoice[0].pop('payment_reference')
                         })
                     if 'amount' in invoice[0].keys():
                         data.update({
-                            "amount": invoice[0].pop('amount')
+                            "amount": int(float(invoice[0].pop('amount')))
                         })                    
                     
                     if 'payment_date' in invoice[0].keys():
