@@ -205,6 +205,24 @@ class Taxes(Resource):
                         "TaxCode": payload.get("type", "")
                     })
 
+            # If client type is ODOO
+            elif super().get_client_type() == super().ODOO:
+                data = {
+                    "active":True
+                }
+                if 'name' in payload.keys():
+                    data.update({
+                        "name": payload.get("name", "")
+                    })
+                if 'type' in payload.keys():
+                    data.update({
+                        "amount_type": payload.get("type", "")
+                    })
+                if 'rate' in payload.keys():
+                    data.update({
+                        "amount": int(payload.get("rate", ""))
+                    })
+
             data.update(additional_properties)
 
             return data
